# Compatibility

The unit tests automatically check compatibility with different versions of OpticStudio against a reference version.
The current reference version is OpticStudio {{ REFERENCE_VERSION }}.

```{include} compatibility_table.md
```

(compatibility/25-1-1)=
## OpticStudio 25.1.1

No known problems.

(compatibility/24-2-2)=
## OpticStudio 24.2.2

No known problems.

(compatibility/24-1-3)=
## OpticStudio 24.1.3

No known problems.

(compatibility/24-1-0)=
## OpticStudio 24.1.0

No known problems.
